@@ -9,7 +9,7 @@ NOT_SET = object()
 
 
 class NoShapeFoundError(Exception):
-     pass
+    pass
 
 
 class InvalidShapeError(Exception):
@@ -191,7 +191,8 @@ class ServiceModel(object):
         'list': ListShape,
         'map': MapShape,
     }
-    def __init__(self, service_description):
+
+    def __init__(self, service_description, service_name=None):
         """
 
         :type service_description: dict
@@ -203,6 +204,14 @@ class ServiceModel(object):
                     open('/path/to/service-description-model.json'))
                 model = ServiceModel(service_description)
 
+        :type service_name: str
+        :param service_name: The name of the service.  Normally this is
+            the endpoint prefix defined in the service_description.  However,
+            you can override this value to provide a more convenient name.
+            This is done in a few places in botocore (ses instead of email,
+            emr instead of elasticmapreduce).  If this value is not provided,
+            it will default to the endpointPrefix defined in the model.
+
         """
         self._service_description = service_description
         # We want clients to be able to access metadata directly.
@@ -210,6 +219,7 @@ class ServiceModel(object):
         self._shape_resolver = ShapeResolver(
             service_description.get('shapes', {}))
         self._signature_version = NOT_SET
+        self._service_name = service_name
 
     def shape_for(self, shape_name, member_traits=None):
         return self._shape_resolver.get_shape_by_name(
@@ -223,12 +233,33 @@ class ServiceModel(object):
             model = self._service_description['operations'][operation_name]
         except KeyError:
             raise OperationNotFoundError(operation_name)
-        return OperationModel(model, self)
+        return OperationModel(model, self, operation_name)
+
+    @CachedProperty
+    def documentation(self):
+        return self._service_description.get('documentation', '')
 
     @CachedProperty
     def operation_names(self):
         return list(self._service_description.get('operations', []))
 
+    @CachedProperty
+    def service_name(self):
+        """The name of the service.
+
+        This defaults to the endpointPrefix defined in the service model.
+        However, this value can be overriden when a ``ServiceModel`` is
+        created.  If a service_name was not provided when the ``ServiceModel``
+        was created and if there is no endpointPrefix defined in the
+        service model, then an ``UndefinedModelAttributeError`` exception
+        will be raised.
+
+        """
+        if self._service_name is not None:
+            return self._service_name
+        else:
+            return self.endpoint_prefix
+
     @CachedProperty
     def signing_name(self):
         """The name to use when computing signatures.
@@ -277,7 +308,7 @@ class ServiceModel(object):
 
 
 class OperationModel(object):
-    def __init__(self, operation_model, service_model):
+    def __init__(self, operation_model, service_model, name=None):
         """
 
         :type operation_model: dict
@@ -288,15 +319,61 @@ class OperationModel(object):
         :type service_model: botocore.model.ServiceModel
         :param service_model: The service model associated with the operation.
 
+        :type name: string
+        :param name: The operation name.  This is the operation name exposed to
+            the users of this model.  This can potentially be different from
+            the "wire_name", which is the operation name that *must* by
+            provided over the wire.  For example, given::
+
+               "CreateCloudFrontOriginAccessIdentity":{
+                 "name":"CreateCloudFrontOriginAccessIdentity2014_11_06",
+                  ...
+              }
+
+           The ``name`` would be ``CreateCloudFrontOriginAccessIdentity``,
+           but the ``self.wire_name`` would be
+           ``CreateCloudFrontOriginAccessIdentity2014_11_06``, which is the
+           value we must send in the corresponding HTTP request.
+
         """
         self._operation_model = operation_model
         self._service_model = service_model
+        self._api_name = name
         # Clients can access '.name' to get the operation name
         # and '.metadata' to get the top level metdata of the service.
-        self.name = operation_model.get('name')
+        self._wire_name = operation_model.get('name')
         self.metadata = service_model.metadata
         self.http = operation_model.get('http', {})
 
+    @CachedProperty
+    def name(self):
+        if self._api_name is not None:
+            return self._api_name
+        else:
+            return self.wire_name
+
+    @property
+    def wire_name(self):
+        """The wire name of the operation.
+
+        In many situations this is the same value as the
+        ``name``, value, but in some services, the operation name
+        exposed to the user is different from the operaiton name
+        we send across the wire (e.g cloudfront).
+
+        Any serialization code should use ``wire_name``.
+
+        """
+        return self._operation_model.get('name')
+
+    @property
+    def service_model(self):
+        return self._service_model
+
+    @CachedProperty
+    def documentation(self):
+        return self._operation_model.get('documentation', '')
+
     @CachedProperty
     def input_shape(self):
         if 'input' not in self._operation_model:
@@ -420,9 +497,15 @@ class DenormalizedStructureBuilder(object):
         }).build_model()
         # ``shape`` is now an instance of botocore.model.StructureShape
 
+    :type dict_type: class
+    :param dict_type: The dictionary type to use, allowing you to opt-in
+                      to using OrderedDict or another dict type. This can
+                      be particularly useful for testing when order
+                      matters, such as for documentation.
+
     """
     def __init__(self, name=None):
-        self.members = {}
+        self.members = OrderedDict()
         self._name_generator = ShapeNameGenerator()
         if name is None:
             self.name = self._name_generator.new_shape_name('structure')
@@ -446,7 +529,7 @@ class DenormalizedStructureBuilder(object):
         :return: The built StructureShape object.
 
         """
-        shapes = {}
+        shapes = OrderedDict()
         denormalized = {
             'type': 'structure',
             'members': self._members,
@@ -471,7 +554,7 @@ class DenormalizedStructureBuilder(object):
             raise InvalidShapeError("Unknown shape type: %s" % model['type'])
 
     def _build_structure(self, model, shapes):
-        members = {}
+        members = OrderedDict()
         shape = self._build_initial_shape(model)
         shape['members'] = members
 
