@@ -18,6 +18,7 @@ import warnings
 from .endpoint import EndpointCreator
 from .operation import Operation
 from .exceptions import ServiceNotInRegionError, NoRegionError
+from .exceptions import ImminentRemovalWarning
 from .exceptions import UnknownEndpointError
 from .model import ServiceModel, OperationModel
 from .translate import denormalize_waiters
@@ -157,7 +158,7 @@ class Service(object):
 
         """
         warnings.warn("get_endpoint is deprecated and will be removed.  "
-                      "Use create_client instead.", DeprecationWarning)
+                      "Use create_client instead.", ImminentRemovalWarning)
         resolver = self.session.get_component('endpoint_resolver')
         region = self.session.get_config_variable('region')
         event_emitter = self.session.get_component('event_emitter')
@@ -185,7 +186,7 @@ class Service(object):
         :param operation_name: The name of the operation.
         """
         warnings.warn("get_operation is deprecated and will be removed.  "
-                      "Use create_client instead.", DeprecationWarning)
+                      "Use create_client instead.", ImminentRemovalWarning)
         for operation in self.operations:
             op_names = (operation.name, operation.py_name, operation.cli_name)
             if operation_name in op_names:
@@ -195,7 +196,7 @@ class Service(object):
     def get_waiter(self, waiter_name, endpoint):
         warnings.warn("get_waiter is deprecated and will be removed.  "
                       "Use client.get_waiter instead.",
-                      DeprecationWarning)
+                      ImminentRemovalWarning)
         try:
             config = self._load_waiter_config()
         except Exception as e:
@@ -206,8 +207,8 @@ class Service(object):
     def _load_waiter_config(self):
         loader = self.session.get_component('data_loader')
         api_version = self.api_version
-        config = loader.load_data('aws/%s/%s.waiters' % (
-            self.service_name, api_version))
+        config = loader.load_service_model(self.service_name,
+                                           'waiters-2', api_version)
         return config
 
 
@@ -227,6 +228,6 @@ def get_service(session, service_name, provider, api_version=None):
     """
     warnings.warn("get_service is deprecated and will be removed.  "
                   "Use Session.create_client instead.",
-                  DeprecationWarning)
+                  ImminentRemovalWarning)
     logger.debug("Creating service object for: %s", service_name)
     return Service(session, provider, service_name)
