@@ -29,9 +29,10 @@ import botocore.credentials
 import botocore.client
 from botocore.endpoint import EndpointCreator
 from botocore.exceptions import EventNotFound, ConfigNotFound, ProfileNotFound
+from botocore.exceptions import ImminentRemovalWarning
 from botocore import handlers
 from botocore.hooks import HierarchicalEmitter, first_non_none_response
-from botocore.loaders import Loader
+from botocore.loaders import create_loader
 from botocore.provider import get_provider
 from botocore.parsers import ResponseParserFactory
 from botocore import regions
@@ -71,9 +72,9 @@ class Session(object):
 
     SessionVariables = {
         # logical:  config_file, env_var,        default_value
-        'profile': (None, 'BOTO_DEFAULT_PROFILE', None),
-        'region': ('region', 'BOTO_DEFAULT_REGION', None),
-        'data_path': ('data_path', 'BOTO_DATA_PATH', None),
+        'profile': (None, ['AWS_DEFAULT_PROFILE', 'AWS_PROFILE'], None),
+        'region': ('region', 'AWS_DEFAULT_REGION', None),
+        'data_path': ('data_path', 'AWS_DATA_PATH', None),
         'config_file': (None, 'AWS_CONFIG_FILE', '~/.aws/config'),
         'provider': ('provider', 'BOTO_PROVIDER_NAME', 'aws'),
 
@@ -164,9 +165,6 @@ class Session(object):
         # This is a dict that stores per session specific config variable
         # overrides via set_config_variable().
         self._session_instance_vars = {}
-        if loader is None:
-            loader = Loader()
-        self._loader = loader
         # _data_paths_added is used to track whether or not we added
         # extra paths to the loader.  We will do this lazily
         # only when we ask for the loader.
@@ -192,12 +190,12 @@ class Session(object):
     def _register_data_loader(self):
         self._components.lazy_register_component(
             'data_loader',
-            lambda:  Loader(self.get_config_variable('data_path') or ''))
+            lambda:  create_loader(self.get_config_variable('data_path')))
 
     def _register_endpoint_resolver(self):
         self._components.lazy_register_component(
             'endpoint_resolver',
-            lambda:  regions.EndpointResolver(self.get_data('aws/_endpoints')))
+            lambda:  regions.EndpointResolver(self.get_data('_endpoints')))
 
     def _register_response_parser_factory(self):
         self._components.register_component('response_parser_factory',
@@ -299,8 +297,9 @@ class Session(object):
                 config_name = None
             if logical_name == 'profile' and self._profile:
                 value = self._profile
-            elif 'env' in methods and envvar_name and envvar_name in os.environ:
-                value = os.environ[envvar_name]
+            elif 'env' in methods and envvar_name and self._handle_env_vars(
+                    envvar_name, os.environ) is not None:
+                value = self._handle_env_vars(envvar_name, os.environ)
             elif 'config' in methods:
                 if config_name:
                     config = self.get_scoped_config()
@@ -314,6 +313,16 @@ class Session(object):
             value = config_default
         return value
 
+    def _handle_env_vars(self, names, environ):
+        # We need to handle the case where names is either
+        # a single value or a list of variables.
+        if not isinstance(names, list):
+            names = [names]
+        for name in names:
+            if name in environ:
+                return environ[name]
+        return None
+
     def set_config_variable(self, logical_name, value):
         """Set a configuration variable to a specific value.
 
@@ -506,27 +515,24 @@ class Session(object):
 
     def get_waiter_model(self, service_name, api_version=None):
         loader = self.get_component('data_loader')
-        latest = loader.determine_latest('%s/%s' % (
-            self.provider.name, service_name), api_version)
-        waiter_path = latest.replace('.normal', '.waiters')
-        waiter_config = loader.load_data(waiter_path)
+        waiter_config = loader.load_service_model(
+            service_name, 'waiters-2', api_version)
         return waiter.WaiterModel(waiter_config)
 
     def get_paginator_model(self, service_name, api_version=None):
         loader = self.get_component('data_loader')
-        latest = loader.determine_latest('%s/%s' % (
-            self.provider.name, service_name), api_version)
-        paginator_path = latest.replace('.normal', '.paginators')
-        paginator_config = loader.load_data(paginator_path)
+        paginator_config = loader.load_service_model(
+            service_name, 'paginators-1', api_version)
         return paginate.PaginatorModel(paginator_config)
 
     def get_service_data(self, service_name, api_version=None):
         """
         Retrieve the fully merged data associated with a service.
         """
-        data_path = '%s/%s' % (self.provider.name, service_name)
+        data_path = service_name
         service_data = self.get_component('data_loader').load_service_model(
             data_path,
+            type_name='service-2',
             api_version=api_version
         )
         event_name = self.create_event('service-data-loaded', service_name)
@@ -538,9 +544,8 @@ class Session(object):
         """
         Return a list of names of available services.
         """
-        data_path = '%s' % self.provider.name
         return self.get_component('data_loader')\
-                .list_available_services(data_path)
+            .list_available_services(type_name='service-2')
 
     def get_service(self, service_name, api_version=None):
         """
@@ -556,7 +561,7 @@ class Session(object):
         :returns: :class:`botocore.service.Service`
         """
         warnings.warn("get_service is deprecated and will be removed.  "
-                      "Use create_client instead.", DeprecationWarning)
+                      "Use create_client instead.", ImminentRemovalWarning)
         service = botocore.service.get_service(self, service_name,
                                                self.provider,
                                                api_version=api_version)
